"""
geopointdb - A package for offline geolocation and geocoding operations.
"""

__version__ = '1.1.0'
__author__ = 'Pulkit Saini'
__email__ = 'pulkitsaini127@gmail.com'
__license__ = 'MIT'
__url__ = 'https://github.com/Pulkit-Py/geopointdb'

from .getpoint import LatLonFinder

__all__ = ['LatLonFinder']
